@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-from .main import DesktopNotifier, Notification, NotificationLevel
+from .main import DesktopNotifier, Button, ReplyField, Notification, Urgency
 
 
-__version__ = "3.0.0"
+__version__ = "3.1.0"
 __author__ = "Sam Schott"
 __url__ = "https://github.com/samschott/desktop-notifier"
